%----------------------------------------
% Imput parameters

inpfile = 'M2.1.model';
outfile = 'M2.1_syn_ell.mat';

mode = 4;

fmin = 0.5;
fmax = 15;
fnum = 1000;

%----------------------------------------
% Initialization

freq = logspace(log10(fmin),log10(fmax),fnum);

%----------------------------------------
% Load data

fid1 = fopen(inpfile,'r');

lnum = str2num(fgetl(fid1));

for nl = 1:lnum
  xxx = sscanf(fgetl(fid1),'%f %f %f %f');
  hl(nl) = xxx(1);
  vp(nl) = xxx(2);
  vs(nl) = xxx(3);
  dn(nl) = xxx(4);
end

fclose(fid1);

%----------------------------------------
% Compute ellipticity

clear mex;
dispersion_curve_init;

ell = ellipticity_curve_rayleigh(hl,vp,vs,dn,freq,mode);

ell = reshape(ell,fnum,mode);

%----------------------------------------
% Save results

save(outfile,'freq','mode','ell');

%------------------------------------------------------
% plot

warning off;

figure(1);
hold on;

for nm = 1:4
  plot3(freq,ell(:,nm),ones(1,fnum),'k','LineWidth',2);
end

%------------------------------------------------------
% Figure Settings

fig_dim = [250 250 600 300];

set(gcf,'Position',fig_dim);
set(gcf,'Renderer','zbuffer');

set(gcf,'Color',[1 1 1]);

set(gca,'TickDir','out');
set(gca,'XMinorTick','on');
set(gca,'YMinorTick','on');
set(gca,'XTick',[[0.1:0.1:0.9],[1:1:9],[10:10:100]]);

set(gca,'XScale','Log');
set(gca,'YScale','Log');

set(gca,'FontWeight','Bold','FontSize',10,'LineWidth',2);

xlabel('Frequency (Hz)');
ylabel('Rayleigh ellipticity');

axis([fmin fmax 0.1 100]);

grid off;
box on;

return;
